===============================
pyzlog
===============================

.. image:: https://img.shields.io/travis/zeeto/pyzlog.svg
        :target: https://travis-ci.org/zeeto/pyzlog

.. image:: https://img.shields.io/pypi/v/pyzlog.svg
        :target: https://pypi.python.org/pypi/pyzlog


Simple python module to standardize logging for applications

* Free software: ISC license
* Documentation: https://pyzlog.readthedocs.org.

Features
--------

* Standard json logging
* Support for custom fields property
* Log file rotation at specified file size
* Configurable number of backup log files
